/*******************************************************************************
 * Copyright (c) 2006 Oracle. All rights reserved.
 * This program and the accompanying materials are made available under the terms of
 * the Eclipse Public License v1.0, which accompanies this distribution and is available at
 * http://www.eclipse.org/legal/epl-v10.html.
 ******************************************************************************/
package org.eclipse.dali.example.jsf.inventory.setup;


import java.sql.Date;
import java.util.Map;

import javax.persistence.EntityManager;


import org.apache.commons.cli.CommandLine;
import org.eclipse.dali.example.jsf.inventory.model.Inventory;
import org.eclipse.dali.example.jsf.inventory.model.Item;
import org.eclipse.dali.example.jsf.inventory.model.Order;


/**
 * <code>PopulateDatabase</code> populates the database with 
 * content for the Dali JPA/JSF demo.
 * 
 * @author Shaun Smith
 * @author Gordon Yorke
 * 
 */

public class PopulateDatabase extends JPACommandLine {
	
	public static void main(String[] args) {
		new PopulateDatabase().run(args);
	}
	
	protected void augmentProperties(Map<String, String> properties) {
		properties.put("toplink.ddl-generation", "drop-and-create-tables");
	}

	@Override
	protected void perform(CommandLine line) {
	    EntityManager em = emf.createEntityManager();
	    em.getTransaction().begin();
		try {
			Item item1 = new Item();
			item1.setCategory("Component");
			item1.setDescription("120GB HardDrive");
			item1.setName("HardDrive120");
			Inventory inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(50.00);
			inv.setPrice(55.0);
			inv.setQuantity(5);
			em.persist(inv);
			
			Order order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);
			
			item1 = new Item();
			item1.setCategory("Component");
			item1.setDescription("400GB HardDrive");
			item1.setName("HardDrive400");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(240.00);
			inv.setPrice(245.0);
			inv.setQuantity(3);
			em.persist(inv);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Component");
			item1.setDescription("80GB HardDrive");
			item1.setName("HardDrive80");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(40.00);
			inv.setPrice(45.0);
			inv.setQuantity(3);
			em.persist(inv);
			
			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Component");
			item1.setDescription("1.7 Ghz Yorez CPU");
			item1.setName("Yorez17");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(240.00);
			inv.setPrice(245.0);
			inv.setQuantity(3);
			em.persist(inv);
			
			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Component");
			item1.setDescription("4.0 Ghz Yorez CPU");
			item1.setName("Yorez40");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(840.00);
			inv.setPrice(945.0);
			inv.setQuantity(3);
			em.persist(inv);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Component");
			item1.setDescription("3.2 Ghz Yorez brand CPU");
			item1.setName("Yorez32");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(350.00);
			inv.setPrice(355.0);
			inv.setQuantity(2);
			em.persist(inv);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Upgrades");
			item1.setDescription("1 MB DIMM ram chip");
			item1.setName("DIMM1");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(150.00);
			inv.setPrice(155.0);
			inv.setQuantity(5);
			em.persist(inv);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Peripheral");
			item1.setDescription("SWGA+ 19 inch Monitor");
			item1.setName("swga19");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(550.00);
			inv.setPrice(555.0);
			inv.setQuantity(5);
			em.persist(inv);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);

			item1 = new Item();
			item1.setCategory("Peripheral");
			item1.setDescription("360 DPI Dotmaxtrix Printer");
			item1.setName("DotMaxOld");
			inv = new Inventory();
			em.persist(item1);
			//set item in inventory after persist to ensure an id is available in
			//item for the foreign key value
			inv.setItem(item1);
			inv.setCost(5.00);
			inv.setPrice(5.50);
			inv.setQuantity(2);
			em.persist(inv);
			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-500000000));
			order.setQuantity(8);
			em.persist(order);

			order = new Order();
			order.setItem(item1);
			order.setOrderInitiated(new Date(System.currentTimeMillis()-800000000));
			order.setArrivalDate(new Date(System.currentTimeMillis()+200000000));
			order.setCurrentLocation("In Transit");
			order.setQuantity(2);
			em.persist(order);
			em.getTransaction().commit();
		} finally {
			em.close();
		}
   	}
		
}
